@@ -3,24 +3,23 @@ from __future__ import annotations
 import asyncio
 import contextlib
 import datetime
+import itertools
 import operator
 import os
 import pathlib
 import random
-from collections.abc import AsyncIterator, Awaitable, Callable
+from collections.abc import AsyncIterator, Awaitable, Callable, Iterator
 from types import MethodType
 from typing import Any
 
 import aiohttp
 import aiohttp_client_cache
 import aiopath
-import asyncstdlib
 import discord
 import discord.ext.commands
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from asyncspotify import Client as SpotifyClient
 from asyncspotify import ClientCredentialsFlow
-from asyncstdlib import itertools
 from discord.abc import Messageable
 from discord.ext.commands import Context
 from discord.types.embed import EmbedType
@@ -97,7 +96,6 @@ from pylav.storage.models.node.real import Node as RealNode
 from pylav.storage.models.player.state import PlayerState
 from pylav.type_hints.bot import DISCORD_BOT_TYPE, DISCORD_COG_TYPE, DISCORD_CONTEXT_TYPE, DISCORD_INTERACTION_TYPE
 from pylav.utils.aiohttp_postgres_cache import PostgresCacheBackend
-from pylav.utils.vendor.redbot import AsyncIter
 
 try:
     from redbot.core.i18n import Translator
@@ -140,7 +138,7 @@ class Client(metaclass=SingletonClass):
         node when it becomes available. This behaviour can be avoided in custom player implementations by
         setting `self._original_node` to `None` in the `change_node` function.
     config_folder: Optional[:class:`pathlib.Path`]
-        The path to the config folder. Defaults to ``CONFIG_DIR``.
+        The path to the settings folder. Defaults to ``CONFIG_DIR``.
     """
 
     _local_node_manager: LocalNodeManager
@@ -453,7 +451,7 @@ class Client(metaclass=SingletonClass):
                 if java_path != JAVA_EXECUTABLE and os.path.exists(JAVA_EXECUTABLE):
                     await self._config.update_java_path(JAVA_EXECUTABLE)
                 LOGGER.info("Lavalink folder: %s", LAVALINK_DOWNLOAD_DIR)
-                LOGGER.info("Config folder: %s", config_folder)
+                LOGGER.info("Settings folder: %s", config_folder)
                 LOGGER.info("Localtracks folder: %s", localtrack_folder)
                 self._config_folder = aiopath.AsyncPath(config_folder)
                 bundled_node_config = self._node_config_manager.bundled_node_config()
@@ -506,7 +504,6 @@ class Client(metaclass=SingletonClass):
         )
 
     async def _run_post_init_jobs(self, java_path) -> None:
-
         self._user_id = str(self._bot.user.id)
         self._local_node_manager = LocalNodeManager(self)
         enable_managed_node = await self.managed_node_is_enabled()
@@ -704,10 +701,10 @@ class Client(metaclass=SingletonClass):
     ):
         yaml_data = await bundled_node_config.fetch_yaml()
         need_update = False
-        if not await asyncstdlib.all([spotify_client_id, spotify_client_secret]):
+        if not all([spotify_client_id, spotify_client_secret]):
             yaml_data["plugins"]["lavasrc"]["sources"]["spotify"] = False
             need_update = True
-        elif await asyncstdlib.all([spotify_client_id, spotify_client_secret]):
+        elif all([spotify_client_id, spotify_client_secret]):
             yaml_data["plugins"]["lavasrc"]["spotify"]["clientId"] = spotify_client_id
             yaml_data["plugins"]["lavasrc"]["spotify"]["clientSecret"] = spotify_client_secret
             yaml_data["plugins"]["lavasrc"]["sources"]["spotify"] = True
@@ -885,11 +882,14 @@ class Client(metaclass=SingletonClass):
             with contextlib.suppress(Exception):
                 return await async_decoder(track)
         if not self.node_manager.available_nodes:
-            raise NoNodeAvailableException(_("No available nodes!"))
+            raise NoNodeAvailableException(_("There are no available nodes!"))
         node = await self.node_manager.find_best_node(feature=feature)
         if node is None and feature:
             raise NoNodeWithRequestFunctionalityAvailableException(
-                _("No node with {feature} functionality available!").format(feature=feature), feature=feature
+                _("No node with {feature_name_variable_do_not_translate} functionality available!").format(
+                    feature_name_variable_do_not_translate=feature
+                ),
+                feature=feature,
             )
         try:
             response = await node.fetch_decodetrack(track, raise_on_failure=raise_on_failure)
@@ -920,11 +920,14 @@ class Client(metaclass=SingletonClass):
             A list of LavalinkTrackObject representing track information.
         """
         if not self.node_manager.available_nodes:
-            raise NoNodeAvailableException(_("No available nodes!"))
+            raise NoNodeAvailableException(_("There are no available nodes!"))
         node = await self.node_manager.find_best_node(feature=feature)
         if node is None and feature:
             raise NoNodeWithRequestFunctionalityAvailableException(
-                _("No node with {feature} functionality available!").format(feature=feature), feature=feature
+                _("No node with {feature_name_variable_do_not_translate} functionality available!").format(
+                    feature_name_variable_do_not_translate=feature
+                ),
+                feature=feature,
             )
         try:
             response = await node.post_decodetracks(tracks, raise_on_failure=raise_on_failure)
@@ -933,7 +936,7 @@ class Client(metaclass=SingletonClass):
             return response
         except Exception:  # noqa
             response_tracks = []
-            async for track in AsyncIter(tracks):
+            for track in tracks:
                 with contextlib.suppress(Exception):
                     response_tracks.append(await async_decoder(track))
             return response_tracks
@@ -996,7 +999,7 @@ class Client(metaclass=SingletonClass):
         event_dispatcher = [self._dispatch_manager.dispatch]
 
         task_list = []
-        async for hook in itertools.chain(
+        for hook in itertools.chain(
             event_dispatcher,
         ):
             task = asyncio.create_task(hook(event))  # type: ignore
@@ -1083,7 +1086,7 @@ class Client(metaclass=SingletonClass):
         requester: discord.Member,
         channel: discord.channel.VocalGuildChannel,
         node: Node = None,
-        self_deaf: bool = True,
+        self_deaf: bool | None = None,
     ) -> Player:
         """|coro|
         Connects the player for the target guild.
@@ -1123,7 +1126,6 @@ class Client(metaclass=SingletonClass):
         footer_url: str = None,
         messageable: Messageable | DISCORD_INTERACTION_TYPE = None,
     ) -> discord.Embed:
-
         if messageable and not colour and not color and hasattr(self._bot, "get_embed_color"):
             colour = await self._bot.get_embed_color(messageable)
         elif colour or color:
@@ -1182,21 +1184,18 @@ class Client(metaclass=SingletonClass):
         await LocalFile.add_root_folder(path=localtrack_folder, create=True)
         return localtrack_folder
 
-    async def get_all_players(self) -> AsyncIterator[Player]:
+    def get_all_players(self) -> Iterator[Player]:
+        return iter(self.player_manager)
 
-        return asyncstdlib.iter(self.player_manager)
-
-    async def get_managed_node(self) -> Node | None:
-        available_nodes = await asyncstdlib.list(
-            asyncstdlib.filter(operator.attrgetter("available"), self.node_manager.managed_nodes)
-        )
+    def get_managed_node(self) -> Node | None:
+        available_nodes = list(filter(operator.attrgetter("available"), self.node_manager.managed_nodes))
 
         return random.choice(available_nodes) if available_nodes else None
 
-    async def get_my_node(self) -> Node | None:
-        return await asyncstdlib.anext(
-            asyncstdlib.filter(lambda n: n.identifier == self.bot.user.id, self.node_manager.managed_nodes),
-            default=None,  # type: ignore
+    def get_my_node(self) -> Node | None:
+        return next(
+            filter(lambda n: n.identifier == self.bot.user.id, self.node_manager.managed_nodes),
+            None,
         )
 
     async def _get_tracks(
@@ -1224,7 +1223,7 @@ class Client(metaclass=SingletonClass):
             A LavalinkLoadTrackObjects representing Lavalink response.
         """
         if not self.node_manager.available_nodes:
-            raise NoNodeAvailableException("No available nodes!")
+            raise NoNodeAvailableException("There are no available nodes!")
         node = await self.node_manager.find_best_node(
             feature=query.requires_capability,
             region=player.region if player else None,
@@ -1232,7 +1231,9 @@ class Client(metaclass=SingletonClass):
         )
         if node is None:
             raise NoNodeWithRequestFunctionalityAvailableException(
-                _("No node with {query.requires_capability} functionality available!").format(query=query),
+                _("No node with {feature_name_variable_do_not_translate} functionality available!").format(
+                    feature_name_variable_do_not_translate=query.requires_capability
+                ),
                 query.requires_capability,
             )
         return await node.get_track(query, first=first, bypass_cache=bypass_cache)
@@ -1521,7 +1522,7 @@ class Client(metaclass=SingletonClass):
     ) -> LoadTrackResponses:
         """This method can be rather slow as it recursively queries all queries and their associated entries.
 
-        Thus, if you are processing user input  you may be interested in using
+        Thus, if you are processing user input you may be interested in using
         the :meth:`get_all_tracks_for_queries` where it can enqueue tracks as needed to the player.
 
 
@@ -1632,7 +1633,7 @@ class Client(metaclass=SingletonClass):
     ) -> bool:
         if additional_user_ids and user.id in additional_user_ids:
             return True
-        if additional_role_ids and await asyncstdlib.any(r.id in additional_role_ids for r in user.roles):
+        if additional_role_ids and any(r.id in additional_role_ids for r in user.roles):
             return True
         return await self.player_config_manager.is_dj(
             user=user, guild=guild, additional_role_ids=None, additional_user_ids=None, bot=bot
@@ -1646,15 +1647,15 @@ class Client(metaclass=SingletonClass):
         playlist_id: str | None = None,
         channel_id: str | None = None,
     ) -> str:
-        if not await asyncstdlib.any([video_id, playlist_id, channel_id, user_id]):
+        if not any([video_id, playlist_id, channel_id, user_id]):
             raise PyLavInvalidArgumentsException(
-                _("To generate a mix playlist a Video, User, Channel or Playlist ID is necessary")
+                _("A single video, user, channel or playlist identifier is necessary to generate a mixed playlist.")
             )
 
-        if await asyncstdlib.sum(1 for i in [video_id, playlist_id, channel_id, user_id] if i) > 1:
+        if sum(1 for i in [video_id, playlist_id, channel_id, user_id] if i) > 1:
             raise PyLavInvalidArgumentsException(
                 _(
-                    "To generate a mix playlist a Video, User, Channel or Playlist ID is necessary. "
+                    "A single video, user, channel or playlist identifier is necessary to generate a mixed playlist. "
                     "However, you provided multiple"
                 )
             )
