@@ -20,7 +20,7 @@ from pylav.type_hints.generics import ANY_GENERIC_TYPE, PARAM_SPEC_TYPE
 try:
     from redbot.core.i18n import Translator
 
-    _ = Translator("PyLavRadio", pathlib.Path(__file__))
+    _ = Translator("PyLav", pathlib.Path(__file__))
 except ImportError:
     Translator = None
 
@@ -90,13 +90,7 @@ def validate_input(
             raise IllegalArgumentError(f"There is no parameter named '{exc.args[0]}'") from exc
         else:
             if not isinstance(value, key_type):
-                raise TypeError(
-                    "Argument {!r} must be {}, not {}".format(
-                        key,
-                        key_type.__name__,
-                        type(value).__name__,
-                    )
-                )
+                raise TypeError(f"Argument {key!r} must be {key_type.__name__}, not {type(value).__name__}")
 
 
 def type_check(
