@@ -4,7 +4,6 @@ import contextlib
 from pathlib import Path
 from typing import TYPE_CHECKING
 
-import asyncstdlib
 import discord
 import humanize
 from redbot.core import i18n
@@ -46,13 +45,25 @@ class NodePickerSource(menus.ListPageSource):
 
         idx_start, page_num = self.get_starting_index_and_page_number(menu)
         page = await self.cog.pylav.construct_embed(messageable=menu.ctx, title=self.message_str)
-        page.set_footer(
-            text=_("Page {page_num}/{total_pages} | {num} nodes").format(
-                page_num=humanize_number(page_num + 1),
-                total_pages=humanize_number(self.get_max_pages()),
-                num=len(self.entries),
-            )
-        )
+
+        total_number_of_entries = len(self.entries)
+        current_page = humanize_number(page_num + 1)
+        total_number_of_pages = humanize_number(self.get_max_pages())
+
+        match total_number_of_entries:
+            case 1:
+                message = _("Page 1 / 1 | 1 entry")
+            case 0:
+                message = _("Page 1 / 1 | 0 entries")
+            case __:
+                message = _(
+                    "Page {current_page_variable_do_not_translate} / {total_number_of_pages_variable_do_not_translate} | {total_number_of_entries_variable_do_not_translate} entries"
+                ).format(
+                    current_page_variable_do_not_translate=current_page,
+                    total_number_of_pages_variable_do_not_translate=total_number_of_pages,
+                    total_number_of_entries_variable_do_not_translate=humanize_number(total_number_of_entries),
+                )
+        page.set_footer(text=message)
         return page
 
     async def get_page(self, page_number):
@@ -142,9 +153,11 @@ class NodeListSource(menus.ListPageSource):
         humanize.i18n.deactivate()
         t_property = EightBitANSI.paint_yellow(_("Property"), bold=True, underline=True)
         t_values = EightBitANSI.paint_yellow(_("Value"), bold=True, underline=True)
-        coordinate_str = EightBitANSI.paint_white(_("Latitude: {lat}\nLongitude: {lon}")).format(
-            lat=EightBitANSI.paint_blue(coord[0] if coord else "?"),
-            lon=EightBitANSI.paint_blue(coord[1] if coord else "?"),
+        coordinate_str = EightBitANSI.paint_white(
+            _("Latitude: {latitude_variable_do_not_translate}\nLongitude: {longitude_variable_do_not_translate}")
+        ).format(
+            latitude_variable_do_not_translate=EightBitANSI.paint_blue(coord[0] if coord else "?"),
+            longitude_variable_do_not_translate=EightBitANSI.paint_blue(coord[1] if coord else "?"),
         )
 
         data = {
@@ -152,9 +165,7 @@ class NodeListSource(menus.ListPageSource):
             EightBitANSI.paint_white(_("Coordinates")): coordinate_str,
             EightBitANSI.paint_white(_("Host")): EightBitANSI.paint_blue(host),
             EightBitANSI.paint_white(_("Port")): EightBitANSI.paint_blue(port),
-            EightBitANSI.paint_white(_("Password")): EightBitANSI.paint_blue(
-                "*" * await asyncstdlib.min([len(password), 10])
-            ),
+            EightBitANSI.paint_white(_("Password")): EightBitANSI.paint_blue("*" * min([len(password), 10])),
             EightBitANSI.paint_white(_("SSL")): secure,
             EightBitANSI.paint_white(_("Available")): connected,
             EightBitANSI.paint_white(_("Search Only")): search_only,
@@ -186,14 +197,25 @@ class NodeListSource(menus.ListPageSource):
             title=node.name,
             description=description,
         )
-        embed.set_footer(
-            text=_("Page {page_num}/{total_pages} | {num} {plural}").format(
-                page_num=humanize_number(page_num + 1),
-                total_pages=humanize_number(self.get_max_pages()),
-                num=len(self.entries),
-                plural=_("nodes") if len(self.entries) != 1 else _("node"),
-            )
-        )
+
+        total_number_of_entries = len(self.entries)
+        current_page = humanize_number(page_num + 1)
+        total_number_of_pages = humanize_number(self.get_max_pages())
+        match total_number_of_entries:
+            case 1:
+                message = _("Page 1 / 1 | 1 node")
+            case 0:
+                message = _("Page 1 / 1 | 0 nodes")
+            case __:
+                message = _(
+                    "Page {current_page_variable_do_not_translate} / {total_number_of_pages_variable_do_not_translate} | {total_number_of_entries_variable_do_not_translate} nodes"
+                ).format(
+                    current_page_variable_do_not_translate=current_page,
+                    total_number_of_pages_variable_do_not_translate=total_number_of_pages,
+                    total_number_of_entries_variable_do_not_translate=humanize_number(total_number_of_entries),
+                )
+
+        embed.set_footer(text=message)
         return embed
 
 
@@ -295,9 +317,11 @@ class NodeManageSource(menus.ListPageSource):
         humanize.i18n.deactivate()
         t_property = EightBitANSI.paint_yellow(_("Property"), bold=True, underline=True)
         t_values = EightBitANSI.paint_yellow(_("Value"), bold=True, underline=True)
-        coordinate_str = EightBitANSI.paint_white(_("Latitude: {lat}\nLongitude: {lon}")).format(
-            lat=EightBitANSI.paint_blue(coord[0] if coord else "?"),
-            lon=EightBitANSI.paint_blue(coord[1] if coord else "?"),
+        coordinate_str = EightBitANSI.paint_white(
+            _("Latitude: {latitude_variable_do_not_translate}\nLongitude: {longitude_variable_do_not_translate}")
+        ).format(
+            latitude_variable_do_not_translate=EightBitANSI.paint_blue(coord[0] if coord else "?"),
+            longitude_variable_do_not_translate=EightBitANSI.paint_blue(coord[1] if coord else "?"),
         )
 
         data = {
@@ -305,9 +329,7 @@ class NodeManageSource(menus.ListPageSource):
             EightBitANSI.paint_white(_("Coordinates")): coordinate_str,
             EightBitANSI.paint_white(_("Host")): EightBitANSI.paint_blue(host),
             EightBitANSI.paint_white(_("Port")): EightBitANSI.paint_blue(port),
-            EightBitANSI.paint_white(_("Password")): EightBitANSI.paint_blue(
-                "*" * await asyncstdlib.min([len(password), 10])
-            ),
+            EightBitANSI.paint_white(_("Password")): EightBitANSI.paint_blue("*" * min([len(password), 10])),
             EightBitANSI.paint_white(_("SSL")): secure,
             EightBitANSI.paint_white(_("Available")): connected,
             EightBitANSI.paint_white(_("Search Only")): search_only,
@@ -339,12 +361,24 @@ class NodeManageSource(menus.ListPageSource):
             title=node.name,
             description=description,
         )
-        embed.set_footer(
-            text=_("Page {page_num}/{total_pages} | {num} {plural}").format(
-                page_num=humanize_number(page_num + 1),
-                total_pages=humanize_number(self.get_max_pages()),
-                num=len(self.entries),
-                plural=_("nodes") if len(self.entries) != 1 else _("node"),
-            )
-        )
+
+        number_of_pages = self.get_max_pages()
+        total_number_of_entries = len(self.entries)
+        current_page = humanize_number(page_num + 1)
+        total_number_of_pages = humanize_number(self.get_max_pages())
+        match number_of_pages:
+            case 1:
+                message = _("Page 1 / 1 | 1 node")
+            case 0:
+                message = _("Page 1 / 1 | 0 nodes")
+            case __:
+                message = _(
+                    "Page {current_page_variable_do_not_translate} / {total_number_of_pages_variable_do_not_translate} | {total_number_of_entries_variable_do_not_translate} nodes"
+                ).format(
+                    current_page_variable_do_not_translate=current_page,
+                    total_number_of_pages_variable_do_not_translate=total_number_of_pages,
+                    total_number_of_entries_variable_do_not_translate=total_number_of_entries,
+                )
+
+        embed.set_footer(text=message)
         return embed
