@@ -3,7 +3,6 @@ from __future__ import annotations
 import typing
 from dataclasses import dataclass
 
-import asyncstdlib
 import discord
 
 from pylav.compat import json
@@ -580,7 +579,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
 
     @maybe_cached
     async def fetch_dj_users(self) -> set[int]:
-        """Fetch the dj users of the player"""
+        """Fetch the disc jockey users of the player"""
         player = (
             await PlayerRow.select(PlayerRow.dj_users)
             .where((PlayerRow.id == self.id) & (PlayerRow.bot == self.bot))
@@ -591,7 +590,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         return set(player["dj_users"] if player else PlayerRow.dj_users.default)
 
     async def add_to_dj_users(self, user: discord.Member) -> None:
-        """Add a user to the dj users of the player"""
+        """Add a user to the disc jockey users of the player"""
         # TODO: When piccolo add support to on conflict clauses using RAW here is more efficient
         #  Tracking issue: https://github.com/piccolo-orm/piccolo/issues/252
         await PlayerRow.raw(
@@ -607,7 +606,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         await self.invalidate_cache(self.fetch_all, self.fetch_dj_users)
 
     async def remove_from_dj_users(self, user: discord.Member) -> None:
-        """Remove a user from the dj users of the player"""
+        """Remove a user from the disc jockey users of the player"""
         # TODO: When piccolo add more functions for dealing with arrays update this to become ORM
         await PlayerRow.raw(
             "UPDATE player SET dj_users = array_remove(dj_users, {}) WHERE id = {} AND bot = {};",
@@ -619,7 +618,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         await self.invalidate_cache(self.fetch_all, self.fetch_dj_users)
 
     async def bulk_add_dj_users(self, *users: discord.Member) -> None:
-        """Add dj users to the player"""
+        """Add disc jockey users to the player"""
         if not users:
             return
         # TODO: When piccolo add support to on conflict clauses using RAW here is more efficient
@@ -637,7 +636,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         await self.invalidate_cache(self.fetch_all, self.fetch_dj_users)
 
     async def bulk_remove_dj_users(self, *users: discord.Member) -> None:
-        """Remove dj users from the player.
+        """Remove disc jockey users from the player.
 
         Parameters
         ----------
@@ -650,7 +649,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
             await self.remove_from_dj_users(user)
 
     async def dj_users_reset(self) -> None:
-        """Reset the dj users of the player"""
+        """Reset the disc jockey users of the player"""
         # TODO: When piccolo add support to on conflict clauses using RAW here is more efficient
         #  Tracking issue: https://github.com/piccolo-orm/piccolo/issues/252
         await PlayerRow.raw(
@@ -667,7 +666,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
 
     @maybe_cached
     async def fetch_dj_roles(self) -> set[int]:
-        """Fetch the dj roles of the player"""
+        """Fetch the disc jockey roles of the player"""
         player = (
             await PlayerRow.select(PlayerRow.dj_roles)
             .where((PlayerRow.id == self.id) & (PlayerRow.bot == self.bot))
@@ -678,7 +677,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         return set(player["dj_roles"] if player else PlayerRow.dj_roles.default)
 
     async def add_to_dj_roles(self, role: discord.Role) -> None:
-        """Add dj roles to the player"""
+        """Add disc jockey roles to the player"""
         # TODO: When piccolo add support to on conflict clauses using RAW here is more efficient
         #  Tracking issue: https://github.com/piccolo-orm/piccolo/issues/252
         await PlayerRow.raw(
@@ -694,7 +693,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         await self.invalidate_cache(self.fetch_all, self.fetch_dj_roles)
 
     async def remove_from_dj_roles(self, role: discord.Role) -> None:
-        """Remove dj roles from the player"""
+        """Remove disc jockey roles from the player"""
         # TODO: When piccolo add more functions for dealing with arrays update this to become ORM
 
         await PlayerRow.raw(
@@ -707,7 +706,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         await self.invalidate_cache(self.fetch_all, self.fetch_dj_roles)
 
     async def bulk_add_dj_roles(self, *roles: discord.Role) -> None:
-        """Add dj roles to the player.
+        """Add disc jockey roles to the player.
 
         Parameters
         ----------
@@ -731,7 +730,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         await self.invalidate_cache(self.fetch_all, self.fetch_dj_roles)
 
     async def bulk_remove_dj_roles(self, *roles: discord.Role) -> None:
-        """Remove dj roles from the player.
+        """Remove disc jockey roles from the player.
 
         Parameters
         ----------
@@ -744,7 +743,7 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
             await self.remove_from_dj_roles(role)
 
     async def dj_roles_reset(self) -> None:
-        """Reset the dj roles of the player"""
+        """Reset the disc jockey roles of the player"""
         # TODO: When piccolo add support to on conflict clauses using RAW here is more efficient
         #  Tracking issue: https://github.com/piccolo-orm/piccolo/issues/252
         await PlayerRow.raw(
@@ -777,27 +776,27 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         additional_user_ids: list | None = None,
         bot: DISCORD_BOT_TYPE = None,
     ) -> bool:
-        """Check if a user is a dj.
+        """Check if a user is a disc jockey.
 
         Parameters
         ----------
         user : discord.Member
             The user to check.
         additional_role_ids : list
-            The additional dj role ids to check.
+            The additional disc jockey role ids to check.
         additional_user_ids : list
-            The additional dj user ids to check.
+            The additional disc jockey user ids to check.
         bot : DISCORD_BOT_TYPE
             The bot instance to check for owners, admins or mods.
 
         Returns
         -------
         bool
-            Whether the user is a dj.
+            Whether the user is a disc jockey.
         """
         if additional_user_ids and user.id in additional_user_ids:
             return True
-        if additional_role_ids and await asyncstdlib.any(r.id in additional_role_ids for r in user.roles):
+        if additional_role_ids and any(r.id in additional_role_ids for r in user.roles):
             return True
         if __ := user.guild:
             if hasattr(bot, "is_owner") and await bot.is_owner(typing.cast(discord.User, user)):
@@ -809,4 +808,4 @@ class PlayerConfig(CachedModel, metaclass=SingletonCachedByKey):
         if await self._userid_in_dj_users(user.id):
             return True
         dj_roles = await self.fetch_dj_roles()
-        return bool(await asyncstdlib.any(r.id in dj_roles for r in user.roles)) if dj_roles else True
+        return bool(any(r.id in dj_roles for r in user.roles)) if dj_roles else True
